<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 

namespace core;


if(!defined('RS-MINI')) die();


/*
 * request v 1.0
 * 
 * Класс получает данные из глобальных массивов и обрабатывает их
 *
 */

class request
{   
    
    /*
     * хранит значение полученное методами getHttpPost(), getHttpGet(), getHttpRequest(), getHttpFiles(), getHttpCookie()
     *
     * @var    - string
     * @access - private
     */
    
    private static $httpData = NULL;
    
    /*
     * получаем данные из глобавльного массива $_SESSION
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
     
    public static function getHttpSession($name)
    {
        self::$httpData = (isset($_SESSION[$name])) ? $_SESSION[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_COOKIE
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
     
    public static function getHttpCookie($name)
    {
        self::$httpData = (isset($_COOKIE[$name])) ? $_COOKIE[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_POST
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
     
    public static function getHttpPost($name)
    {
        self::$httpData = (isset($_POST[$name])) ? $_POST[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_GET
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
    
    public static function getHttpGet($name)
    {
        self::$httpData = (isset($_GET[$name])) ? $_GET[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_REQUEST
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
    
    public static function getHttpRequest($name)
    {
        self::$httpData = (isset($_REQUEST[$name])) ? $_REQUEST[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_FILES
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
    
    public static function getHttpFiles($name)
    {
        self::$httpData = (isset($_FILES[$name])) ? $_FILES[$name] : NULL;
        return new request();
    }
    
    /*
     * получаем данные из глобавльного массива $_SERVER. В основном метод написан для получение HTTP_HOST и REQUEST_URI ключей
     * 
     * @access - public
     * @return - объект класса request
     * 
     * @param string name - ключ элемента массива
     */
    
    public static function getHttpServer($name)
    {
        self::$httpData = (isset($_SERVER[$name])) ? $_SERVER[$name] : NULL;
        return new request();
    }
    
    /*
     * обрабатывает данные в свойстве self::$httpData как стороку
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toString()
    {
        return addslashes(htmlspecialchars(self::$httpData));
    }
    
    /*
     * обрабатывает данные в свойстве self::$httpData как html
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toHtml()
    {
        return addslashes(self::$httpData);
    }

    /*
     * обрабатывает данные в свойстве self::$httpData как целое число
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toInteger()
    {
        return (int)self::$httpData;
    }
    
    /*
     * обрабатывает данные в свойстве self::$httpData как число с плавующей точкой
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toFloat()
    {
        return (float)self::$httpData;
    }

    /*
     * обрабатывает данные в свойстве self::$httpData как ссылку.
     * использовать метод только для значения глобального массива $_SERVER['REQUEST_URI']
     * получает строку БЕЗ параметров
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toUri()
    {
        // пропускаем строку через декодер урлов. чистим от пробелов и приводим у нижнему регистру
        self::$httpData  = urldecode(trim(mb_strtolower(self::$httpData)));
        // бьем урл на массив по знаку вопроса
        $uri             = explode('?', self::$httpData);
        // сохраняем все что до знака вопроса
        self::$httpData  = $uri[0];
        
        // если урл равен слешу (главная страница)
        if (self::$httpData == '/')
            // возвращаем его
            return self::$httpData;
                
        // пробиваем по регулярному выражению
        if (!preg_match("/^[-_\.a-z0-9\/]+[\/]{1}$/s", self::$httpData))
            return NULL;
            
        return self::$httpData;
    }
    
    /*
     * метод принудительно вставляет значение в свойство httpData. После чего его можно обработать методами преобразования
     * 
     * @access - public
     * @return - объект класса request
     *
     * @param ??? data - присланные данные
     */
    
    public function setData($data)
    {
        self::$httpData = $data;
        
        return new request();
    }
    
    /*
     * в отличие от остальных методов, просто возвращает полученные данные
     * 
     * @access - public
     * @return - данные или null если ничего не найдено
     * 
     */
    
    public function getData()
    {
        return self::$httpData;
    }
}
